@@ -92,12 +92,36 @@ check_err_msg <- function(err.msg){
 
   # Only allow numeric (real & integer) values in the specified columns
   data.types <- vapply(X = data, FUN = .MFclass, FUN.VALUE = "")
-  data.types <- data.types[num.only.cols]
+  data.types.have.to.be.num <- data.types[num.only.cols]
 
-  if(any(!(data.types %in% "numeric")))
+  if(any(!(data.types.have.to.be.num %in% "numeric")))
     err.msg <- c(err.msg, paste0("Please only provide numeric data for the regressors ",
                                  paste(num.only.cols, collapse = ", "), "."))
 
+  # do not allow non.finite values in any of the relevant columns
+  rel.data <- data[, all.vars(formula(F.formula, rhs=rhs.rel.regr)), drop=FALSE]
+
+  # Check for NA among all variables, incl character
+  #  also check for NA first with anyNA first because much faster than !is.finite
+  if(anyNA(rel.data)){
+    err.msg <- c(err.msg, "Please do not provide any NA values in the data.")
+    return(err.msg)
+  }
+
+  #  Do is.finite only do for numeric data and if dont have
+  #   any NAs (alloc mem for whole dataset)
+  #   !sapply same as sapply(,!is.finite)
+  numeric.are.finite <- sapply(rel.data, function(col){
+    if(is.numeric(col))
+      return(is.finite(col))
+    else
+      # all other types (chars etc) are seen as not finite.
+      # Checking for NA not needed because done before
+      return(TRUE)})
+
+  if(any(!unlist(numeric.are.finite)))
+    err.msg <-c(err.msg, "Please do not provide any non-finite values in the data.")
+
   return(err.msg)
 }
 
@@ -196,13 +220,13 @@ checkinputhelper_startparams <- function(start.params, F.formula,
     if(!(n %in% names(start.params)))
       err.msg <- c(err.msg, paste0("Please provide the start parameter for ", n, "."))
 
-  # check that no parameter is named a forbidden name
-  if(any(names(start.params) %in% forbidden.names))
-    err.msg <- c(err.msg, paste0("Please provide none of the following parameters:",paste(paste0("\'", forbidden.names, "\'"), collapse = ","),"."))
+    # check that no parameter is named a forbidden name
+    if(any(names(start.params) %in% forbidden.names))
+      err.msg <- c(err.msg, paste0("Please provide none of the following parameters:",paste(paste0("\'", forbidden.names, "\'"), collapse = ","),"."))
 
 
-  # Exactly one for every formula var: Done with length check & that every is present
-  return(err.msg)
+    # Exactly one for every formula var: Done with length check & that every is present
+    return(err.msg)
 }
 
 checkinputhelper_charactervector <- function(vec, parameter.name, allowed.inputs){
@@ -227,7 +251,7 @@ checkinputhelper_charactervector <- function(vec, parameter.name, allowed.inputs
       err.msg <- c(err.msg, paste("Please provide only elements from c(",paste(allowed.inputs, collapse = ", "),
                                   ") for \'",parameter.name,"\'.", sep = ""))
 
-  return(err.msg)
+    return(err.msg)
 }
 
 
@@ -242,8 +266,9 @@ checkinputhelper_formula_IIVs <- function(formula){
     return("Please specify the formula with exactly 3 or 4 parts on the right-hand side")
 
   # Check that every RHS2 is in RHs
-  names.rhs1 <- all.vars(formula(F.formula, rhs=1, lhs=0))
-  names.rhs2 <- all.vars(formula(F.formula, rhs=2, lhs=0))
+  # all.vars do not account for transformations, ie log(P) and P is the same. Use labels(terms) instead
+  names.rhs1 <- labels(terms(formula(F.formula, rhs=1, lhs=0)))
+  names.rhs2 <- labels(terms(formula(F.formula, rhs=2, lhs=0)))
   # RHS2 not in RHS1
   if(!all(names.rhs2 %in% names.rhs1))
     err.msg <- c(err.msg, "Please specify every endogenous regressors also in the first right-hand side (main model) of the formula.")
@@ -303,10 +328,7 @@ checkinputhelper_dataVSformula_IIV <- function(formula, data){
                                                             rhs.rel.regr = relevant.cols.for.datacols,
                                                             num.only.cols = num.only.cols)
 
-  # Check that no column is named IIV.NUMBER. *** TODO: ADAPT
-  if(any(grepl(pattern = "^IIV\\.[0-9]", x = colnames(data))))
-    err.msg <- c(err.msg, paste0("Please name no column in the data \'IIV.NUMERIC"))
-  #**?? Check that no column is named iivs or g to avoid confusion wh
+  # No need to check that columns are not named iiv or g because that is caught as given double
 
   return(err.msg)
 }
